@@ -27,7 +27,7 @@
 //#include <kdebug.h>
 //#include "iostream"
 #include "adif.h"
-using namespace std;
+//using namespace std;
 /*
 This class is really not independant FROM the GUI as the numbers to codify the
 MODE and BANDS depend on the position of the band in the COMBO-box.
@@ -275,30 +275,32 @@ int Adif::mode2Int(const QString& tmode){
 }
 
 int Adif::freq2Int (const QString& tfreq){ // Receives MHz/String
-// cout << "Adif::freq2Int: " << tfreq << endl;
+// Due to float precision the band limits are not exact!
+//cout << "Adif::freq2Int: " << tfreq << endl;
+
 	freq = (tfreq.toFloat());
 	
-   if ((freq >=0.136)&&(freq <=0.137)){
+   if ((freq >=0.135)&&(freq <=0.138)){
     return 1000;
-   }else if ((freq >=1.8)&&(freq <=2.0)){
+   }else if ((freq >=1.7)&&(freq <=2)){
     return 0;
-   }else if ((freq >=3.5)&&(freq <=4.0)){
+   }else if ((freq >=3.4)&&(freq <=4)){
     return 1;
-   }else if ((freq >= 5.102)&&(freq <=5.404)){
+   }else if ((freq >= 5.101)&&(freq <=5.405)){
     return 2;
-   }else if ((freq >= 7)&&(freq <=7.3)){
+   }else if ((freq >= 7)&&(freq <=7.4)){
     return 3;
-  }else if ((freq >= 10)&&(freq <=10.15)){
+  }else if ((freq > 10.1)&&(freq <10.17)){
     return 4;
   }else if ((freq >= 14)&&(freq <=14.35)){
     return 5;
-  }else if ((freq >= 18.068)&&(freq <=18.168)){
+  }else if ((freq >= 18.067)&&(freq <=18.169)){
     return 6;
-  }else if ((freq >= 21)&&(freq <=21.45)){
+  }else if ((freq >= 21)&&(freq <=21.46)){
     return 7;
-  }else if ((freq >= 24.89)&&(freq <=24.99)){
+  }else if ((freq >= 24.88)&&(freq <=24.991)){
     return 8;
-  }else if ((freq >=28)&&(freq <=29.7)){
+  }else if ((freq >=28)&&(freq <=29.8)){
     return 9;
   }else if ((freq >=50)&&(freq <=54)){
     return 10;
@@ -335,6 +337,7 @@ int Adif::freq2Int (const QString& tfreq){ // Receives MHz/String
    }else if ((freq >=241000)&&(freq <=250000)) {
      return 1026;
   }else{
+//cout << "Adif::freq2Int: NOBAND found" << endl;
     return -1;
     // If Band is not in this "list" it is still not supported
   }
@@ -347,13 +350,13 @@ QString Adif::getModeBandPlan(const QString& tfreq){ // (in MHz)
 
 
 
-   if ((freq >=1.810)&&(freq < 1.84)){
+   if ((freq >=1.80)&&(freq < 1.84)){
     return "CW";
-   }else if ((freq >=1.840)&&(freq <=2.000)){
+   }else if ((freq >=1.839)&&(freq <=2.000)){
     return "SSB";
    }else if ((freq >=3.5)&&(freq < 3.6)){
     return "CW";
-   }else if ((freq >=3.6)&&(freq <=4.0)){
+   }else if ((freq >=3.5)&&(freq <=4.0)){
     return "SSB";
    }else if ((freq >=7.0)&&(freq < 7.04)){
     return "CW";
@@ -410,8 +413,13 @@ QString Adif::getModeBandPlan(const QString& tfreq){ // (in MHz)
 
 QString Adif::freq2Band (const QString& tfreq){ // MHz
 //cout << "Adif::freq2Band: " << tfreq << endl;
+//cout << "Adif::freq2Band-L: " << tfreq.left((tfreq.find("."))+2) << endl;
+
+
+//	return int2Band(freq2Int(QString::number(((tfreq.left(tfreq.find("."))).toInt()))));
+
+return int2Band(freq2Int( tfreq.left((tfreq.find("."))+2) ));
 
-	return int2Band(freq2Int(QString::number(((tfreq.left(tfreq.find("."))).toInt()))));
 }
 
 QString Adif::int2Band(int tband){
