@@ -26,7 +26,7 @@
 //#include "iostream"
 #include "awarddxcc.h"
 
-using namespace std;
+//using namespace std;
 
 //-1 Not worked, 0 = worked, 1 = confirmed
 AwardDXCC::AwardDXCC(){
