@@ -24,6 +24,10 @@
 
 //#include <klocale.h>
 
+//#include "iostream"
+
+//using namespace std;
+
 #include "awards.h"
 Awards::Awards(){
 	listOfAwards.clear();
@@ -94,18 +98,20 @@ QString Awards::getAwardName (const QString &tprefix){
 			return (*it).getAwardName();
 		}
 	}
-	return "Award";
+	return awardDefault.getAwardName();
 }
 
 Award Awards::getAwardFor(const QString &tprefix){
-//cout << "Awards::getAwardFor() " << endl;
+//cout << "Awards::getAwardFor() " << tprefix << endl;
  	awardAux = awardDefault;
 	ListOfAwards::iterator it;
 	for ( it = listOfAwards.begin(); it != listOfAwards.end(); ++it ){
 		if ((*it).checkPrefix(tprefix)){
+//cout << "Awards::getAwardFor() " << "Found award: " << (*it).getAwardName() << endl;
 			return (*it);
 		}
 	}
+//cout << "Awards::getAwardFor() " << "No award found for this prefix" << endl;
 	return awardDefault; // If we did not found the award for this prefix we simply return
 
 }
