@@ -1,6 +1,6 @@
-#include <klocale.h>
+//#include <klocale.h>
 //#include <kdebug.h>
-//#include <ostream.h>
+
 #include "dxspot.h"
 
 
