@@ -17,10 +17,10 @@
 
 #include "kloghamlib.h"
 //#include "iostream"
-
+//using namespace std;
 //#include "ostream.h" // This is to be deleted before releasing as it is just for debuging
 
-using namespace std;
+//using namespace std;
 
 kloghamlib::kloghamlib(){
 //cout << "KLogHamlib::constructor" << endl;
@@ -31,7 +31,7 @@ kloghamlib::kloghamlib(){
 	bauds = 4800;
 	dataBits = 8;
 	stopBits = 1;
-	serialPort = "/dev/ttyUSB0";
+	serialPort = "";
 	radioStatus ="hamlib: not init";
 }
 
@@ -49,62 +49,62 @@ kloghamlib::~kloghamlib(){
 
 
 bool kloghamlib::init(){
-	//cout << "KLogHamlib::init" << endl;
-	//cout << "KLogHamLib: RigNumber: " << QString::number(myrig_model) << endl;
+//	cout << "KLogHamlib::init" << endl;
+//	cout << "KLogHamLib: RigNumber: " << QString::number(myrig_model) << endl;
 	if (myrig_model == -1)
 		return false;
 	if (!rigLaunched){
- 		//cout << "Rig not launched... beginging of launching..." << endl;
+//		cout << "Rig not launched... beginging of launching..." << endl;
 		rig_set_debug(RIG_DEBUG_NONE); 
-		//cout << "KlogHamlib::init - 1" << endl;
+//		cout << "KlogHamlib::init - 1" << endl;
 		port_t myport;// may be overriden by backend probe
 		myport.type.rig = RIG_PORT_SERIAL;
-		//cout << "KlogHamlib::init - 2" << endl;
+//		cout << "KlogHamlib::init - 2" << endl;
 		myport.parm.serial.rate = bauds;
-		//cout << "KlogHamlib::init - 3" << endl;
+//		cout << "KlogHamlib::init - 3" << endl;
 		myport.parm.serial.data_bits = 8;
-		//cout << "KlogHamlib::init - 4" << endl;
+//		cout << "KlogHamlib::init - 4" << endl;
 		myport.parm.serial.stop_bits = 1;
-		//cout << "KlogHamlib::init - 5" << endl;
+//		cout << "KlogHamlib::init - 5" << endl;
 		myport.parm.serial.parity = RIG_PARITY_NONE;
-		//cout << "KlogHamlib::init - 6" << endl;
+//		cout << "KlogHamlib::init - 6" << endl;
 		myport.parm.serial.handshake = RIG_HANDSHAKE_NONE;
-		//cout << "KlogHamlib::init - 7" << endl;
+//		cout << "KlogHamlib::init - 7" << endl;
 		//strncpy(myport.pathname, SERIAL_PORT, FILPATHLEN);
 		strncpy(myport.pathname, serialPort, FILPATHLEN);
-		//cout << "KlogHamlib::init - 8" << endl;
+//		cout << "KlogHamlib::init - 8" << endl;
 		// rig_load_all_backends();
-		// myrig_model = rig_probe(&myport);  
+		// myrig_model = rig_probe(&myport);
 		radio = rig_init(myrig_model);
-		//cout << "KlogHamlib::init - 9" << endl;
+//		cout << "KlogHamlib::init - 9" << endl;
 		if (!radio) {
 			rigLaunched = false;
 			// TODO: To make some error visible with qmessages and so on
-			//fprintf(stderr,"Unknown rig num: %d\n", myrig_model);
-			//fprintf(stderr,"Please check riglist.h\n");
+			fprintf(stderr,"Unknown rig num: %d\n", myrig_model);
+			fprintf(stderr,"Please check riglist.h\n");
 			return false;
 			//     exit(1); // whoops! something went wrong (mem alloc?) 
 		}
-		//cout << "KlogHamlib::init - 10" << endl;
-		strncpy(radio->state.rigport.pathname,SERIAL_PORT,FILPATHLEN);
-		//cout << "KlogHamlib::init - 10.1" << endl;
+//		cout << "KlogHamlib::init - 10" << endl;
+		strncpy(radio->state.rigport.pathname,serialPort,FILPATHLEN);
+//		cout << "KlogHamlib::init - 10.1" << endl;
 		retcode = rig_open(radio);
-		//cout << "KlogHamlib::init - 10.2" << endl;
+//		cout << "KlogHamlib::init - 10.2" << endl;
 		if (retcode != RIG_OK) {
-			//cout << "KlogHamlib::init - 10.3" << endl;
+//			cout << "KlogHamlib::init - 10.3" << endl;
 			rigLaunched = false;
-			//cout << "KlogHamlib::init - 10.4" << endl;
+//			cout << "KlogHamlib::init - 10.4" << endl;
 			// TODO: To make some error visible with qmessages and so on
-			//printf("rig_open: error = %s\n", rigerror(retcode));
-			//cout << "KlogHamlib::init - 10.5" << endl;
+			printf("rig_open: error = %s\n", rigerror(retcode));
+//			cout << "KlogHamlib::init - 10.5" << endl;
 			return false;
 			//    exit(2);
 		}
-		//cout << "KlogHamlib::init - 10.6" << endl;
+//		cout << "KlogHamlib::init - 10.6" << endl;
 		//printf("Port %s opened ok\n", serialPort);
-		//cout << "KlogHamlib::init - 10.7" << endl;
+//		cout << "KlogHamlib::init - 10.7" << endl;
 		rigLaunched = true;
-		//cout << "KlogHamlib::init - 11" << endl;
+//		cout << "KlogHamlib::init - 11" << endl;
 	}else{
 		//cout << "Rig is launched" << endl;
 	}
