@@ -26,7 +26,7 @@
 //#include <kdebug.h>
 //#include "iostream"
 #include "qso.h"
-using namespace std;
+//using namespace std;
 
 Qso::Qso(){
 }
@@ -43,6 +43,8 @@ Qso::Qso(const QString& tqrz, int tnumb, QString& tmode){
   myGridSquare = "NULL";
   stx=-1;
   srx=-1;
+	nr_pings = -1;
+	sfi=-1;
   stx_string="";
   srx_string="";
   dxcc = 0;
@@ -68,7 +70,9 @@ Qso::Qso(const int tnumb, const QString& tqrz, const int trstrx, const int trstt
 	dxcc = 0;
   stx=-1;
   srx=-1;
-  stx_string="";
+	sfi=-1;
+	nr_pings = -1;
+  	stx_string="";
   srx_string="";
   contest_id="";
   station_callsign="";
@@ -94,10 +98,13 @@ Qso::Qso(const int tnumb, const QDateTime tdateTime, const QString& tqrz, const
 	dxcc = 0;
   stx=-1;
   srx=-1;
+	sfi=-1;
+	nr_pings = -1;
   stx_string="";
   srx_string="";
   contest_id="";
   station_callsign="";
+  check="";
 }
 
 Qso::Qso (const int tnumb, const QDateTime& tdateTime, const QString& tqrz, const int trstrx, const int trsttx, int tband, const QString& tmode, const int tpower, const QDate& tqslSen,  const QDate& tqslRec, const QString& tcomment){
@@ -120,6 +127,8 @@ Qso::Qso (const int tnumb, const QDateTime& tdateTime, const QString& tqrz, cons
   dxcc = 0;
   stx=-1;
   srx=-1;
+  nr_pings = -1;
+	sfi=-1;
   stx_string="";
   srx_string="";
   contest_id="";
@@ -137,6 +146,55 @@ int Qso::getAge() const{return age;};		// Contacted operator age in years
 void Qso::setA_index (int tnumb){a_index = tnumb;}; // geomagnetic A index at the time of the QSO
 int Qso::getA_index() const{return a_index;};	// geomagnetic A index at the time of the QSO
 
+void Qso::setK_index (int tnumb){k_index = tnumb;}; // geomagnetic K index at the time of the QSO
+int Qso::getK_index() const{return k_index;};	// geomagnetic K index at the time of the QSO
+
+void Qso::setMaxBursts (int tnumb){maxbursts = tnumb;}; 
+int Qso::getMaxBursts() const{return maxbursts;};	
+void Qso::setNRBursts (int tnumb){nr_bursts = tnumb;}; 
+int Qso::getNRBursts() const{return nr_bursts;};	
+void Qso::setNRPings (int tnumb){nr_pings = tnumb;}; 
+int Qso::getNRPings() const{return nr_pings;};	
+void Qso::setSFI (int tnumb){sfi = tnumb;}; 
+int Qso::getSFI() const{return sfi;};
+
+void Qso::setSatMode(const QString &tsat){
+	sat_mode = tsat;
+}
+QString Qso::getSatMode() const{return sat_mode;}
+void Qso::setSatName(const QString &tsat){
+	sat_name = tsat;
+}
+QString Qso::getSatName() const{return sat_name;}
+	
+
+void Qso::setMSShower(const QString &tmsshower){	//For Meteor Scatter QSOs, the name of the meteor shower in progress
+	msshower = checkisNotAdif(tmsshower);
+}
+ QString Qso::getMSShower() const{return msshower;}
+
+
+void Qso::setOwnerCall(const QString &tstring){
+	owner_callsign = checkisNotAdif(tstring);
+}
+
+QString Qso::getOwnerCall() const{return owner_callsign;}
+
+void Qso::setPfx(const QString &tstring){
+	pfx = checkisNotAdif(tstring);
+}
+QString Qso::getPfx() const{return pfx;}
+
+void Qso::setPrecedence(const QString &tstring){
+	precedence = checkisNotAdif(tstring);
+}	
+
+QString Qso::getPrecedence() const{return precedence;}
+
+
+
+
+
 void Qso::setAnt_az (int tnumb){	//Antenna azimut in degrees
 	if ((tnumb>=0)&&(tnumb<=360)){
 		ant_az = tnumb;
@@ -205,7 +263,7 @@ int Qso::getRsttx() const{
 }
 
 void Qso::setCQz (int tnumb){
-	if ((tnumb>=0) && (tnumb>=40)){
+	if ((tnumb>=0) && (tnumb<=40)){
 		cqz = tnumb;
 	}else{
 		cqz = -1;
@@ -215,7 +273,7 @@ void Qso::setCQz (int tnumb){
 int Qso::getCQz() const {return cqz;}
 void Qso::setITUz (int tnumb){
 //TODO: Check how many ITU zones are O:-)
-	if ((tnumb>=0) && (tnumb>=100)){
+	if ((tnumb>=0) && (tnumb<=100)){
 		ituz = tnumb;
 	}else{
 		ituz = -1;
@@ -224,8 +282,31 @@ void Qso::setITUz (int tnumb){
 }
 int Qso::getITUz() const{return ituz;}
 
+
+
+
+void Qso::setMyCQz (int tnumb){
+	if ((tnumb>=0) && (tnumb<=40)){
+		my_cqz = tnumb;
+	}else{
+		my_cqz = -1;
+	}
+}
+
+int Qso::getMyCQz() const {return my_cqz;}
+void Qso::setMyITUz (int tnumb){
+//TODO: Check how many ITU zones are, 90?
+	if ((tnumb>=0) && (tnumb<=100)){
+		my_ituz = tnumb;
+	}else{
+		my_ituz = -1;
+	}
+
+}
+int Qso::getMyITUz() const{return my_ituz;}
+
+
 void Qso::setDistance (int tnumb){
-//TODO: Check how many ITU zones are O:-)
 	if (tnumb>0){
 		distance = tnumb;
 	}else{
@@ -238,7 +319,7 @@ int Qso::getDistance() const{return distance;}
 
 void Qso::setBand (const QString& tband){
 //TODO: I may set also a default freq per band when calling this function
-// 14000 when 20m, 21000 when 15m and so on...
+// 100 when 20m, 21000 when 15m and so on...
 // Some kind of checking would be great.
 // Importing adif.h and using "bool ifValidBand" from here would be ok but
 // I am trying to avoid importing adif.h here.
@@ -300,6 +381,19 @@ void Qso::setMode(const QString& tmode){
 void Qso::setDXCC (int tnumb){dxcc = tnumb;};
 int Qso::getDXCC() const{return dxcc;};	
 
+void Qso::setCountry(const QString& tcountry){	// ADIF DXCC Country name
+	country = checkisNotAdif(tcountry);
+}
+
+QString Qso::getCountry() const{return country;}			// ADIF DXCC Country name
+
+void Qso::setMyCountry(const QString& tcountry){	// ADIF DXCC Country name
+	my_country = checkisNotAdif(tcountry);
+}
+
+QString Qso::getMyCountry() const{return my_country;}			// ADIF DXCC Country name
+
+
 QString Qso::getMode() const{
     return mode;}
 
@@ -496,6 +590,19 @@ void Qso::setIota(const QString &tiota){
 QString Qso::getIota() const{
     return iota;}
 
+void Qso::setMyIota(const QString &tiota){
+// TODO:
+// It is necessary to check the received QString to  allow only valid IOTA
+// references (CC-XXX)
+	//cout << "QSO::setIota: " << tiota << endl;
+	my_iota = checkisNotAdif(tiota);
+}
+
+QString Qso::getMyIota() const{
+    return my_iota;}
+
+
+
 void Qso::setLocalAward(const QString &taward){
 	//cout << "QSO::setLocalAward: " << taward << endl;
 	localAward = checkisNotAdif(taward);
@@ -521,6 +628,15 @@ int Qso::getIotaNumber() const {
   return (iota.section('-',1,1)).toInt();
 }
 
+
+QString Qso::getMyIotaContinent() const{
+  return my_iota.section('-',0,0);
+}
+
+int Qso::getMyIotaNumber() const {
+  return (my_iota.section('-',1,1)).toInt();
+}
+
 void Qso::setName(const QString &tname){
   name = checkisNotAdif(tname);
 }
@@ -529,6 +645,129 @@ QString Qso::getName() const{
   return name;
 }
 
+void Qso::setMyName(const QString &tname){
+  my_name = checkisNotAdif(tname);
+}
+
+QString Qso::getMyName() const{
+  return my_name;
+}
+
+void Qso::setAddress (const QString& taddress) {
+	address = checkisNotAdif(taddress);
+}
+
+QString Qso::getAddress() const{
+	return address;
+}
+
+void Qso::setMyPostalCode (const QString& taddress) {
+	my_postal_code = checkisNotAdif(taddress);
+}
+
+QString Qso::getMyPostalCode() const{
+	return my_postal_code;
+}
+
+void Qso::setMyStreet (const QString& taddress) {
+	my_street = checkisNotAdif(taddress);
+}
+
+QString Qso::getMyStreet() const{
+	return my_street;
+}
+
+void Qso::setMyState (const QString& taddress) {
+	my_state = checkisNotAdif(taddress);
+}
+
+QString Qso::getMyState() const{
+	return my_state;
+}
+
+void Qso::setARRLSect (const QString& tarrls){
+//TODO: Check if it is a valid ARRL Section from the ADIF specs
+	arrl_sect = checkisNotAdif(tarrls);
+}
+
+QString Qso::getARRLSect() const{
+	return arrl_sect;
+}
+
+void Qso::setMyRig (const QString& taux){
+	my_rig = checkisNotAdif(taux);
+}
+
+QString Qso::getMyRig() const{
+	return my_rig;
+}
+
+
+void Qso::setMySig (const QString& taux){
+	 my_sig = checkisNotAdif(taux);
+}
+
+QString Qso::getMySig() const{
+	return my_sig;
+}
+
+void Qso::setMySigInfo (const QString& taux){
+	 my_sig_info = checkisNotAdif(taux);
+}
+
+QString Qso::getMySigInfo() const{
+	return my_sig_info;
+}
+
+void Qso::setSigInfo (const QString& taux){
+	 sig_info = checkisNotAdif(taux);
+}
+
+QString Qso::getSigInfo() const{
+	return sig_info;
+}
+
+void Qso::setSig (const QString& taux){
+	 sig = checkisNotAdif(taux);
+}
+
+QString Qso::getSig() const{
+	return sig;
+}
+
+void Qso::setPublicKey (const QString& taux){
+	 public_key = checkisNotAdif(taux);
+}
+
+QString Qso::getPublicKey() const{
+	return public_key;
+}
+
+void Qso::setQsoRandom  (bool taux){
+	  qso_random = taux;
+}
+
+bool Qso::getQsoRandom() const{
+	return qso_random;
+}
+
+void Qso::setSwl  (bool taux){
+	 swl = taux;
+}
+
+bool Qso::getSwl() const{
+	return swl;
+}
+
+void Qso::setTenten  (const int taux){
+	  ten_ten = taux;
+}
+
+int Qso::getTenten() const{
+	return ten_ten;
+}
+
+
 void Qso::setContinent(const QString &tcont){
 	if ( (tcont == "NA") || (tcont == "SA") || (tcont == "EU") || (tcont == "AF") || (tcont == "OC") || (tcont == "") || (tcont == "AS") || (tcont == "AN")  ){
 		cont = tcont;
@@ -570,6 +809,15 @@ QString Qso::getQth() const{
   return qth;
 }
 
+void Qso::setMyCity(const QString &tqth){
+  my_city = checkisNotAdif(tqth);
+}
+
+QString Qso::getMyCity() const{
+  return my_city;
+}
+
+
 void Qso::setOperator(const QString &toperator){
     operatorc = checkisNotAdif(toperator);
 }
@@ -586,6 +834,7 @@ QString Qso::getStationCallsign() const{                // Call used to work thi
 }
 
 void Qso::setPropMode(const QString &tprop_mode){
+// TODO: Check if the propmode is correct before saving (ADIF has a table of valid data)
   prop_mode = checkisNotAdif(tprop_mode);
 }
 
@@ -601,8 +850,12 @@ void Qso::setStx (int tnumb){stx = tnumb;};
 int Qso::getStx() const {return stx;};
 void Qso::setStx_string(const QString &tstx){stx_string = checkisNotAdif(tstx);};
 QString Qso::getStx_string() const{return stx_string;};
-void Qso::setContestID(const QString &tcontestid){contest_id = tcontestid;};
+void Qso::setContestID(const QString &tcontestid){contest_id = checkisNotAdif(tcontestid);};
 QString Qso::getContestID() const{return contest_id;};
+void Qso::setCheck(const QString &tcheck){check = checkisNotAdif(tcheck);}; // Contest check
+QString Qso::getCheck() const{return check;};                // Contest check
+void Qso::setClass(const QString &tcclass){cclass = checkisNotAdif(tcclass);}; // Contest class
+QString Qso::getClass() const{return cclass;};                // Contest class
 
 
 
@@ -626,30 +879,46 @@ void Qso::clearQso(){
 	qslVia = "";     // QSL_VIA (C) //Manager
 	qslInfo = ""; //;    // ADDRESS /QSLMSG
 	comment = "";    // COMMENT
+	address = "";
 	//  int qslHow;         // How is the qsl to be send
 	manager = "";
 	gridSquare = "";
+	myGridSquare = "";
 	iota = "AF-0";   // GRIDSQUARE
+	my_iota = "AF-0";   // GRIDSQUARE
 	operatorc = "";   // OPERATOR
 	name = "";       // NAME
 	qth = "";        // QTH
+	my_city="";
 	localAward = "0"; // LocalAward
 	localAwardNumber = 0; // Just for managing, not saved in the log
+	dxcc=0;
+	country="";
+	my_country="";
 	freq = "0.0"; // Frecuency
 	freq_rx = freq;
 	rx_power = "0"; //RX_PWR
 	power = "0"; //TX_PWR
 	age = -1;
 	a_index=-1;
+	k_index=-1;
+	sfi=-1;
 	contest_id="";
+	cclass="";
+	check="";
 	ant_az=-1;	
 	ant_el=-1;	//Antena elevation
 	ant_path='N'; // NULL
 	band_rx="";
 	cont='N';
 	contacted_op ="";
+	maxbursts=-1;
+	nr_bursts=-1;
+	nr_pings = -1;
 	cqz = -1;
 	ituz = -1;
+	my_cqz = -1;
+	my_ituz = -1;
 	distance = -1;
 	email ="";
 	eq_call="";  // The contacted station's owner's callsign
@@ -659,6 +928,9 @@ void Qso::clearQso(){
 	stx_string="";	// Contest stuff;
 	contest_id="";
 	station_callsign="";
+	arrl_sect="";
+	msshower="";
+	my_city="";
 }
 
 QString Qso::checkisNotAdif(const QString& tword){
