@@ -93,6 +93,12 @@ public:
 	void setDXCC (int tnumb);	// ADIF DXCC Country code
 	int getDXCC() const;		// ADIF DXCC Country code
 
+	void setCountry(const QString& tcountry);	// ADIF DXCC Country name
+	QString getCountry() const;			// ADIF DXCC Country name
+
+	void setMyCountry(const QString& tcountry);	// ADIF DXCC Country name
+	QString getMyCountry() const;			// ADIF DXCC Country name
+
 	void setAge (int tnumb);	// Contacted operator age in years
 	int getAge() const;		// Contacted operator age in years
 
@@ -104,6 +110,8 @@ public:
 
 	void setA_index (int tnumb); // geomagnetic A index at the time of the QSO
 	int getA_index() const;	// geomagnetic A index at the time of the QSO
+	void setK_index (int tnumb); // geomagnetic K index at the time of the QSO
+	int getK_index() const;	// geomagnetic K index at the time of the QSO
 
 
    void setQslSenDateOn(QDate tdate);
@@ -154,6 +162,12 @@ public:
   QString getIotaContinent() const;
   int getIotaNumber() const;
 
+  void setMyIota(const QString &tiota);
+  QString getMyIota() const;
+  QString getMyIotaContinent() const;
+  int getMyIotaNumber() const;
+
+
   void setLocalAward(const QString &taward);
   QString getLocalAward() const;
 
@@ -163,6 +177,24 @@ public:
   void setName(const QString &tname);
   QString getName() const; 
 
+  void setMyName(const QString &tname);
+  QString getMyName() const; 
+
+  void setAddress (const QString& taddress);
+  QString getAddress() const;
+
+  void setMyPostalCode (const QString& taddress);
+  QString getMyPostalCode() const;
+
+  void setMyStreet (const QString& taddress);
+  QString getMyStreet() const;
+
+  void setMyState (const QString& taddress);
+  QString getMyState() const;
+
+  void setARRLSect (const QString& tarrls);
+  QString getARRLSect() const;
+
   void setContinent(const QString &tcont);
   QString getContinent() const; 
 
@@ -184,12 +216,21 @@ public:
   void setITUz (int tnumb);
   int getITUz() const;
 
+  void setMyCQz (int tnumb);
+  int getMyCQz() const;
+  void setMyITUz (int tnumb);
+  int getMyITUz() const;
+
+
   void setDistance (int tnumb);
   int getDistance() const;
 
   void setQth(const QString &tqth);
   QString getQth() const;
 
+  void setMyCity(const QString &tqth);
+  QString getMyCity() const;
+
   void setOperator(const QString &toperator); // Operator that works this QSO
   QString getOperator() const;                // Operator that works this QSO
 
@@ -199,6 +240,55 @@ public:
  void setPropMode(const QString &tprop_mode);
  QString getPropMode() const;
 
+ void setSatMode(const QString &tsat);
+ QString getSatMode() const;
+ void setSatName(const QString &tsat);
+ QString getSatName() const;
+
+ void setMaxBursts (int tnumb);	//maximum length of meteor scatter bursts heard by the logging station, in seconds
+ int getMaxBursts() const;
+
+ void setNRBursts (int tnumb);	
+ int getNRBursts() const;
+
+ void setNRPings (int tnumb);	
+ int getNRPings() const;
+
+ void setSFI (int tnumb);	
+ int getSFI() const;
+
+ void setMSShower(const QString &tmsshower);	//For Meteor Scatter QSOs, the name of the meteor shower in progress
+ QString getMSShower() const;
+
+ void setOwnerCall(const QString &tstring);	
+ QString getOwnerCall() const;
+ void setPfx(const QString &tstring);	
+ QString getPfx() const;
+ void setPrecedence(const QString &tstring);	
+ QString getPrecedence() const;
+
+void setMyRig (const QString& taux);
+QString getMyRig() const;
+void setMySig (const QString& taux);
+QString getMySig() const;
+void setMySigInfo (const QString& taux);
+QString getMySigInfo() const;
+void setSigInfo (const QString& taux);
+QString getSigInfo() const;
+void setSig (const QString& taux);
+QString getSig() const;
+void setPublicKey (const QString& taux);
+QString getPublicKey() const;
+
+// WORK 3+
+void setQsoRandom  (bool taux);
+bool getQsoRandom() const;
+void setSwl  (bool taux);
+bool getSwl() const;
+void setTenten  (const int taux);
+int getTenten() const;
+/////////////////////
+
 /********************* CONTESTS ********************/
 	void setSrx (int tnumb);
 	int getSrx() const;
@@ -210,6 +300,10 @@ public:
 	QString getStx_string() const;
 	void setContestID(const QString &tcontestid); // Contest identifier
 	QString getContestID() const;                // Contest identifier
+	void setCheck(const QString &tcheck); // Contest check
+	QString getCheck() const;                // Contest check
+	void setClass(const QString &tcheck); // Contest Class
+	QString getClass() const;                // Contest Class
 
 /********************* CONTESTS ********************/
 
@@ -232,6 +326,7 @@ private:
   QString band_rx;       // BAND_RX
 
 	int dxcc;	// ADIF DXCC country code
+  QString country;	// ADIF DXCC country Name
   QString mode;       // MODE
   QString rx_power;   // RX_PWR
   QString power;      // TX_PWR
@@ -240,6 +335,7 @@ private:
   QDate eqsl_qslrdate;	//EQSL_QSLRDATE
   QDate eqsl_qslsdate;	//EQSL_QSLSDATE
   QString comment;    // COMMENT
+  QString address;    // ADDRESS
   QChar qslRecc;      // QSL_RCVD Y, N, R, I
   QChar qslSenc;      // QSL_SENT Y, N, R, I
   QChar eQSL_qsl_rcvd; // eQSL_RCVD Y, N, R, I, V
@@ -258,20 +354,75 @@ private:
   QString operatorc;   // OPERATOR/Call(only if not station_callsign is present) used to work this QSO
   QString contacted_op; // the callsign of the individual operating the  contacted station
   QString eq_call;	//The  contacted station's owner's callsign
+  QString check;	// contest check
+  QString cclass;	// contest class
   QString state;    // STATE
   QString name;       // NAME
   QString cont;		// Contacted Continent
   QString qth;        // QTH
   QString email;	// Contacted station's email
   QString web;		// Contacted station's web
+  QString arrl_sect;		// Contacted station's ARRL Section
   int age;		// Contacted operator age in years
   int a_index;		// geomagnetic A index at the time of the QSO
+  int k_index;		// geomagnetic K index at the time of the QSO
   int ant_az;	//Antenna azimut in degrees
   int ant_el;	//Antena elevation
   int cqz;
   int ituz;
   int distance;
+  int maxbursts;	// maximum length of meteor scatter bursts heard by the logging station, in seconds
+  QString msshower;
   QString prop_mode;  // PROP_MODE QSO propagation mode
+  int my_cqz;	
+  int my_ituz;	
+  QString my_iota;
+  QString my_city;
+  QString my_country;
+  QString my_name;
+  QString my_postal_code;
+  QString my_street;
+  QString my_state;
+  int nr_bursts;
+  int nr_pings;
+  int sfi;		// the solar flux at the time of the QSO
+  QString sat_mode;	
+  QString sat_name;	
+  QString owner_callsign;	
+  QString pfx;
+  QString precedence;	
+
+  QString my_rig;
+  QString my_sig;
+  QString my_sig_info;
+  QString sig;
+  QString sig_info;
+  QString public_key;
+
+//TODO: Add support for the following ADIF data:
+// Adding support means at least:
+// 1- create the set and get functions in the QSO class
+// 2- Initialize and/or clear it appropriately in qso.clear()
+// 3- Save this data in the adifTempFileSave in Klog class
+// 4- Read this data in the processLogLine in the Klog class
+
+
+  int my_lat;
+  int my_lon;
+  int lat;
+  int lon;
+
+  bool qso_random;	// 1&2
+  bool swl;		// 1&2
+  int ten_ten;		// 1&2
+
+
+  QString notes; // Multiline... but similar to comment?
+  QString rig; // Multiline... 
+  QString qso_complete; //(Char)
+
+///////////////////////////////////////////////////////
+
 /***************** CONTEST FIELDS *************************/
 	int srx;		//contest QSO received serial number
 	int stx;		//contest QSO transmitted serial number
