@@ -3,7 +3,7 @@
                              -------------------
     begin                : sb may 21 2005
     copyright            : (C) 2005 by Jaime Robles
-    email                : jaime@robles.nu
+    email                : jaime@robles.es
  ***************************************************************************/
 
 /******************************************************************************
@@ -29,6 +29,7 @@
 #include <klocale.h>
 
 
+
 class Reference{
 public:
 	Reference();
