@@ -28,7 +28,7 @@
 //#include "iostream"
 #include "world.h"
 
-using namespace std; 
+//using namespace std; 
  
 World::World(){
   prefix = "NULL"; // It is just a fake prefix to start with
@@ -224,7 +224,11 @@ void World::create(){
 
 QString World::getPrefix(const QString tqrz){
 	aux = findEntity(tqrz);
-	return prefix;
+
+return (getEntByNumb(aux)).getPfx();
+
+
+//	return prefix;
 }
 
 
@@ -238,57 +242,71 @@ QString World::getPrefix(const QString tqrz){
 
 int World::findEntity(const QString string){
 // If no Entity is found, we return "0"
+//cout << "World::findEntity: " << string << endl;
 
 // The first task is to isolate the prefix
 
-  prefixa = string;
-  prefixab = string;
-  prefix = "NULL";
-  qrz = prefixa;      // For last checks
-  qrz2 = qrz;
-  i = 0;
+	prefixa = string;
+	prefixab = string;
+	prefix = "NULL";
+	qrz = prefixa;      // For last checks
+	qrz2 = qrz;
+	i = 0;
+	if (prefixa.contains('\\')){
+//		cout << "World::findEntity: " << "Contains invert / so changes to /" << endl;
+		prefixa.replace(QChar('\\'), QChar('/'));
+//		cout << "World::findEntity look: " << prefixa << endl;
+	}
 
-  if(( (prefixa.contains('/')) || (prefixa.contains('\\')) )){
-    i = giveEnt(prefixa); // Checking full "special prefixes" like "4U/OH2BBF" first
-    if (i!=0){
-      return i;
-    }
-    if (prefixa.endsWith("/")||prefixa.endsWith("\\")){ // We look for calls ending in slash "/" or "\"
-      prefixa.remove(prefixa.length()-1,1);
-    }
-    if (prefixa.contains('/')){
-      ij = prefixa.find('/');
-      if ( (abs)(ij) < (abs)((prefixa.length())- ij)  ) { //Like in F/EA4TV
-        prefixab = prefixa.left(ij);
-        qrz2 = prefixab;
-      }else{ // Like in EA4TV/F
-        if (!((prefixa.upper()).endsWith("/P"))	// Portable
-        && !((prefixa.upper()).endsWith("/MM"))  // Maritime mobile
-        && (!(prefixa.upper()).endsWith("/B"))	// Beacon
-        && !((prefixa.upper()).endsWith("/M"))	//Mobile
-        && !((prefixa.upper()).endsWith("/J"))  // JOTA Scout
-        && (!(prefixa.upper()).endsWith("/LH")) // Light House
-        && (!(prefixa.upper()).endsWith("/QRP"))
-        && (!(prefixa.upper()).endsWith("/0"))
-        && (!(prefixa.upper()).endsWith("/1"))
-        && (!(prefixa.upper()).endsWith("/2"))
-        && (!(prefixa.upper()).endsWith("/3"))
-        && (!(prefixa.upper()).endsWith("/4"))
-        && (!(prefixa.upper()).endsWith("/5"))
-        && (!(prefixa.upper()).endsWith("/6"))
-        && (!(prefixa.upper()).endsWith("/7"))
-        && (!(prefixa.upper()).endsWith("/8"))
-        && (!(prefixa.upper()).endsWith("/9"))) {
-	// It is necessary to check for special prefixes like /r = Rotuma or /a = Mount Athos...
-	// So let's go
-          if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("3D2" )) ){
-          // This is Conway Reef
-            prefixa = "3D2AM";
-            return giveEnt(prefixa);
-          }
-         if ( (prefixa.upper().endsWith("/R")) && (prefixa.upper().startsWith("3D2" )) ){
-         // This is Rotuma
-	prefixa = "3D2AA";
+	if (prefixa.contains('/')) {
+//		cout << "World::findEntity contains /: " << prefixa << endl;
+		i = giveEnt(prefixa); // Checking full "special prefixes" like "4U/OH2BBF" first
+		if (i!=0){
+			return i;
+		}
+		if (prefixa.endsWith("/") ){ // We look for calls ending in slash "/" or "\"
+//			cout << "World::findEntity ends with /: " << prefixa << endl;
+			prefixa.remove(prefixa.length()-1,1);
+//			cout << "World::findEntity remove the / so: " << prefixa << endl;
+		}
+		if (prefixa.contains('/')){
+			ij = prefixa.find('/');
+
+			n = (prefixa.length())- ij; // n is the length of the second part
+			if (n < 0){
+				n = -n;
+			}
+
+			if ( ij < n ) { //Like in F/EA4TV
+				prefixab = prefixa.left(ij);
+				qrz2 = prefixab;
+			}else { // Like in EA4TV/F
+				if (!((prefixa.upper()).endsWith("/P"))	// Portable
+				&& !((prefixa.upper()).endsWith("/MM"))  // Maritime mobile
+				&& (!(prefixa.upper()).endsWith("/B"))	// Beacon
+				&& !((prefixa.upper()).endsWith("/M"))	//Mobile
+				&& !((prefixa.upper()).endsWith("/J"))  // JOTA Scout
+				&& (!(prefixa.upper()).endsWith("/LH")) // Light House
+				&& (!(prefixa.upper()).endsWith("/QRP"))
+				&& (!(prefixa.upper()).endsWith("/0"))
+				&& (!(prefixa.upper()).endsWith("/1"))
+				&& (!(prefixa.upper()).endsWith("/2"))
+				&& (!(prefixa.upper()).endsWith("/3"))
+				&& (!(prefixa.upper()).endsWith("/4"))
+				&& (!(prefixa.upper()).endsWith("/5"))
+				&& (!(prefixa.upper()).endsWith("/6"))
+				&& (!(prefixa.upper()).endsWith("/7"))
+				&& (!(prefixa.upper()).endsWith("/8"))
+				&& (!(prefixa.upper()).endsWith("/9"))){
+				// It is necessary to check for special prefixes like /r = Rotuma or /a = Mount Athos...
+					if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("3D2" )) ){
+          						// This is Conway Reef
+						prefixa = "3D2CI";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/R")) && (prefixa.upper().startsWith("3D2" )) ){
+					// This is Rotuma
+						prefixa = "3D2AG/P";
 						return giveEnt(prefixa);
 					}
 					if ( (prefixa.upper().endsWith("/B")) && (prefixa.upper().startsWith("3Y" )) ){
@@ -296,6 +314,7 @@ int World::findEntity(const QString string){
 						prefixa = "3Y";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("FK" )) ){
 					// This is Chesterfield Is.
 						prefixa = "TX0AT";
@@ -311,115 +330,145 @@ int World::findEntity(const QString string){
 						prefixa = "FO0AAA";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/G")) && (prefixa.upper().startsWith("FR" )) ){
-					// This is Glorioso Is.
+							// This is Glorioso Is.
 						prefixa = "FR/G";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/J")) && (prefixa.upper().startsWith("FR" )) ){
 					// This is Juan de Nova & Europa Is.
 						prefixa = "FR4FA";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/T")) && (prefixa.upper().startsWith("FR" )) ){
 					// This is Tromelin Is.
 						prefixa = "FR/T";
 						return giveEnt(prefixa);
-            				}
+					}
+
 					if ( (prefixa.upper().endsWith("/S")) && (prefixa.upper().startsWith("GM" )) ){
 					// This is Shetland Is.
 						prefixa = "2M1ANT";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/A")) && (prefixa.upper().startsWith("HK0" )) ){
 					// This is San Andres/Providencia Is.
 						prefixa = "HK0";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("HK0" )) ){
 					// This is Malpelo Is.
 						prefixa = "5J0M";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("JD" )) ){
 					// This is Minami Torishima Is.
 						prefixa = "7J1ACH";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("JD" )) ){
 					// This is Ogasawara Is.
 						prefixa = "7J1ATZ";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/B")) && (prefixa.upper().startsWith("JW" )) ){
 					// This is Bear Is.
 						prefixa = "JW2FL";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/A")) && (prefixa.upper().startsWith("SV" )) ){
-					// This is Mount Athos Is.
+						// This is Mount Athos Is.
 						prefixa = "SY2A";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/D")) && (prefixa.upper().startsWith("VP6" )) ){
 					// This is Ducie Is.
 						prefixa = "VP6DI";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/G")) && (prefixa.upper().startsWith("VP8" )) ){
 					// This is South Georgia Is.
 						prefixa = "VP8BUB";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/H")) && (prefixa.upper().startsWith("VP8" )) ){
 					// This is South Shetland Is.
 						prefixa = "4K1ADQ";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("VP8" )) ){
 					// This is South Orkney Is.
 						prefixa = "AY1ZA";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("VP8" )) ){
 					// This is South Sandwich Is.
 						prefixa = "4K1ZI";
 						return giveEnt(prefixa);
 					}
+
 					if ( (prefixa.upper().endsWith("/N")) && (prefixa.upper().startsWith("ZK1" )) ){
 					// This is North Cook Is.
 						prefixa = "ZK1AAH";
 						return giveEnt(prefixa);
 					}
 					//TODO Check this prefixab = prefixa;
-            				prefixab = prefixa; prefixa.right(prefixa.length()-(ij+1));
+				
+					//prefixab = prefixa;
+					prefixa = prefixa.right(prefixa.length()-(ij+1));
+					
+//					cout << "Should be the shortest: " << prefixa << endl;
+
+					prefixab = prefixa;
+					//return i;
+
 				}else{  // It is a EA4TV/P or EA4TV/QRP    
 					// Peter I, is a special "/P" station... so we need to check it.
-
+//					cout << "Es un corto especial-1: " << prefixa << endl;
 					if ( (prefixa.upper().endsWith("/P")) && (prefixa.upper().startsWith("3Y" )) ){
 						// This is Peter I
-						prefixa = "3Y0PI";
+						//prefixa = "3Y0PI";
+						prefixa = "3Y0X";
 						return giveEnt(prefixa);
-					}
+					}else if ( ( (prefixa.upper()).endsWith("/M")) && ((prefixa.upper()).startsWith("FO" )) ){
 					// Marquesas, is a special "/M" station... so we need to check it.     
-					if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("FO" )) ){
-					// This is Marquesas Is.
-						prefixa = "FO/DL1AWI";
+//					cout << "Marquesas!: " << prefixa << endl;	
+						prefixa = "FO/OH1RX";
 						return giveEnt(prefixa);
-					}
-					prefixab =  prefixa.left(ij);
-					if ((prefixa.upper().endsWith("/M"))||(prefixa.upper().endsWith("/MM"))){// /M and /MM does not count as DXCC
+					}else if ( ((prefixa.upper()).endsWith("/M"))||((prefixa.upper()).endsWith("/MM"))){
+// /M and /MM does not count as DXCC
+//						cout << "/M Normal; " << prefixa << endl;
 						return 0;
 					}else{// Normal /p, /m, ... prefix
-// 			cout << "world::findEntity: Its a special Call-2: " << prefixa << endl;
-					}
+//						cout << "Portable/mobile/maritime NORMAL: " << prefixa << endl;	
+						//return 0;
+					}								
 				}
-			qrz2 = prefixab;
-	}
-	
-    }else{
-      ij = prefixa.find("\\");
-      if ( (abs)(ij) < (abs)(prefixa.length()-ij ) ) { //Like in F\EA4TV
+				qrz2 = prefixab;
+			} // end of contains a / but it is not a EA4TV/F nor F/EA4TV
+    		}else{ // It does not have any /
+//			cout << "World::findEntity does not have /: " << prefixa << endl;
+      			ij = prefixa.find("\\");
+			n = (prefixa.length())- ij;
+			if (n < 0){
+				n = -n;
+			}
+
+      if (ij < n ) { //Like in F\EA4TV
         prefixab = prefixa.right(prefixa.length() - ij);
         qrz2 = prefixab;
       }else{// Like in F\EA4TV
@@ -447,78 +496,78 @@ int World::findEntity(const QString string){
    prefixa.truncate(1);
    i = giveEnt(prefixa);
       }
-  }else if ((prefixa.at(2)).isDigit()){ // The third character is a number as in EA4T
-      prefixa.truncate(4); // looking for VP2M, VK9X, ...
-      i = giveEnt(prefixa);
-      if (i == 0){  // Looking for EA6, ZS8, VK9...
-   prefixa = prefixab;
-   prefixa.truncate(3);
-   i = giveEnt(prefixa);
-   if (i != 0){
-       return i; // We've got it! So no more checkings.
-   }
-      }else{
-   return i;  // We've got it! So no more checkings.
-      }
-      prefixa = prefixab;   // Looking for EA, VK, ZS, ...
-      prefixa.truncate(2);
-      i = giveEnt(prefixa);
+	}else if ((prefixa.at(2)).isDigit()){ // The third character is a number as in EA4T
+		prefixa.truncate(4); // looking for VP2M, VK9X, ...
+		i = giveEnt(prefixa);
+		if (i == 0){  // Looking for EA6, ZS8, VK9...
+			prefixa = prefixab;
+			prefixa.truncate(3);
+			i = giveEnt(prefixa);
+			if (i != 0){
+				return i; // We've got it! So no more checkings.
+			}
+		}else{
+			return i;  // We've got it! So no more checkings.
+		}
+		prefixa = prefixab;   // Looking for EA, VK, ZS, ...
+		prefixa.truncate(2);
+		i = giveEnt(prefixa);
 
-  }else if ((prefixa.at(3)).isDigit()){ // The forth character is a number as in 3DA0SV
-      prefixa.truncate(4); // We will look for 3DA0 or 3XY7C
-      i = giveEnt(prefixa);
-      if (i == 0){
-   prefixa = prefixab;
-   prefixa.truncate(3);
-   i = giveEnt(prefixa);
-      }
-  }
-  if (i == 0){ // I want to look for calls like RA3AA or NA3A
-  // The real prefix is just one letter but the next char is NOT a number
-  // so the first condition is not satistied.
-      prefixa = prefixab;
-      if ((prefixa.at(2)).isDigit()){
-   prefixa.truncate(1);
-   i = giveEnt(prefixa);
-      }
-  }else{ // If it is not 0, we have detected the Entity. No reason to keep running this.
-      return i;
-  }
-  if (i == 0){
-      i = giveEnt(qrz);
-  }else{ // If it is not 0, we have detected the Entity. No reason to keep running this.
-      return i;
-  }
+	}else if ((prefixa.at(3)).isDigit()){ // The forth character is a number as in 3DA0SV
+		prefixa.truncate(4); // We will look for 3DA0 or 3XY7C
+			i = giveEnt(prefixa);
+			if (i == 0){
+				prefixa = prefixab;
+				prefixa.truncate(3);
+				i = giveEnt(prefixa);
+			}
+		}
+		if (i == 0){ // I want to look for calls like RA3AA or NA3A
+		// The real prefix is just one letter but the next char is NOT a number
+		// so the first condition is not satistied.
+		prefixa = prefixab;
+		if ((prefixa.at(2)).isDigit()){
+			prefixa.truncate(1);
+			i = giveEnt(prefixa);
+		}
+	}else{ // If it is not 0, we have detected the Entity. No reason to keep running this.
+		return i;
+	}
+	if (i == 0){
+		i = giveEnt(qrz);
+	}else{ // If it is not 0, we have detected the Entity. No reason to keep running this.
+		return i;
+	}
 
-  if (i == 0){ // We have to test for calls as 5U when reading from a log file
-    i = giveEnt(qrz2);
-  }else{
-     return i;
- }
-  if (i == 0){  // We have to test for calls as KL7 when
+	if (i == 0){ // We have to test for calls as 5U when reading from a log file
+		i = giveEnt(qrz2);
+	}else{
+		return i;
+	}
+	if (i == 0){  // We have to test for calls as KL7 when
                   // reading from a log file as we truncate -1 to look for KL
-      qrz2.truncate(qrz2.length() -1);
-      i = giveEnt(qrz2);
-  }else{
-      return i;
-  }
+		qrz2.truncate(qrz2.length() -1);
+		i = giveEnt(qrz2);
+	}else{
+		return i;
+	}
 
   // We have to check for calls as 3XY1L when reading from a file
   // but just if we have not find another Entity
-  if (i == 0){
-      if ( ((prefixa.at(3)).isDigit()) && !(prefixa.at(2).isDigit())){ // The forth character is a number as in 3DA0SV
-   prefixa.truncate(2); // We will look for 3X
-   i = giveEnt(prefixa);
-   if (i == 0){
-       prefixa.truncate(1); // Maybe it is a F like station
-       i = giveEnt(prefixa);
-   }
-}else if((prefixa.at(0)).isDigit()){ // HACK: Looking for 3XDQC stile calls
-    prefixa.truncate(2);
-    i = giveEnt(prefixa);
-}
-}
-  return i; // "i" is the Entity number
+  	if (i == 0){
+      		if ( ((prefixa.at(3)).isDigit()) && !(prefixa.at(2).isDigit())){ // The forth character is a number as in 3DA0SV
+   			prefixa.truncate(2); // We will look for 3X
+   			i = giveEnt(prefixa);
+   			if (i == 0){
+       				prefixa.truncate(1); // Maybe it is a F like station
+       				i = giveEnt(prefixa);
+   			}
+		}else if((prefixa.at(0)).isDigit()){ // HACK: Looking for 3XDQC stile calls
+    			prefixa.truncate(2);
+    			i = giveEnt(prefixa);
+		}
+	}
+  	return i; // "i" is the Entity number
 }
 
 
